@@ -20,15 +20,11 @@ if sys.version_info[0] >= 3:
     from urllib.request import urlopen
     from urllib.error import HTTPError
     _str_type = str
-    from collections import UserDict
-    from collections import UserList
 else:
     from urllib import urlencode, quote
     from urllib2 import urlopen
     from urllib2 import HTTPError
     _str_type = basestring
-    from UserList import UserList
-    from UserDict import IterableUserDict as UserDict
 
 
 def safe_encode(kwargs):
@@ -39,7 +35,7 @@ def safe_encode(kwargs):
     return urlencode(kwargs)
 
 
-class Service:
+class Service(object):
     """
     Base class for all the API implementations, as well as a bunch of common
     code on how to actually fetch text over the network.
@@ -95,23 +91,23 @@ class Service:
             raise ex
 
 
-class EntityList(UserList):
+class EntityList(list):
     """
     EntityList provides an iterable of API entities along with a _meta
     dictionary that contains information about the query results. This could
     include result count and pagination details.
     """
     def __init__(self, data=[], meta=None):
-        UserList.__init__(self, data)
+        list.__init__(self, data)
         self._meta = meta
 
 
-class EntityDict(UserDict):
+class EntityDict(dict):
     """
     EntityDict provides a dictionary representation of an API entity along
     with a _meta dictionary that contains information about the query results.
     This could include result count and pagination details.
     """
     def __init__(self, data={}, meta=None):
-        UserDict.__init__(self, data)
+        dict.__init__(self, data)
         self._meta = meta
