@@ -11,10 +11,11 @@ Sunlight Congress API Implementation inside ``python-sunlight``.
 import sunlight.service
 from sunlight.service import EntityDict, EntityList
 from sunlight.pagination import pageable
+from sunlight.errors import SunlightException
 import json
 
 
-API_ROOT = "https://congress.api.sunlightfoundation.com"
+API_DOMAIN = "congress.api.sunlightfoundation.com"
 
 LEGISLATOR_ID_TYPES = (
     'bioguide',
@@ -53,10 +54,33 @@ class Congress(sunlight.service.Service):
     Bindings to the `Congress API <http://sunlightlabs.github.io/congress/>`_.
     Keep in mind this is a thin wrapper around the API so the API documentation
     is the place to look for help on field names and examples.
+
+    By default, the API runs over https. You can set `congress.use_https = False` or
+    `congress = Congress(use_https=False)` to use regular http.
     """
 
     is_pageable = True
 
+    def __init__(self, use_https=True):
+        super(Congress, self).__init__()
+        self._selected_protocol = 'https'
+        self.use_https = use_https
+
+    @property
+    def use_https(self):
+        """
+            This API supports https and regular http. Default is to use https
+        """
+        return self._use_https
+
+    @use_https.setter
+    def use_https(self, value):
+        self._use_https = value
+        if self._use_https:
+            self._selected_protocol = 'https'
+        else:
+            self._selected_protocol = 'http'
+
     @pageable
     def legislators(self, **kwargs):
         """
@@ -278,6 +302,28 @@ class Congress(sunlight.service.Service):
         """
         return self.get(['nominations'], **kwargs)
 
+    @pageable
+    def congressional_documents(self, **kwargs):
+        """
+        Search congressional documents including House witness documents and
+        House committee reports.
+
+        For details see `Congressional documents API docs
+        <https://sunlightlabs.github.io/congress/congressional_documents.html>`_
+        """
+        return self.get(['congressional_documents', 'search'], **kwargs)
+
+    @pageable
+    def documents(self, **kwargs):
+        """
+        Search oversight documents including Government Accountability Office reports and
+        Inspectors General reports.
+
+        For details see `Documents API docs
+        <https://sunlightlabs.github.io/congress/documents.html>`_
+        """
+        return self.get(['documents'], **kwargs)
+
     # implementation methods
     def _get_url(self, pathparts, apikey, **kwargs):
         url_args = preencode_values(flatten_dict(kwargs))
@@ -285,8 +331,9 @@ class Congress(sunlight.service.Service):
         # join pieces by slashes and add a trailing slash
         endpoint_path = "/".join(pathparts)
 
-        url = "{api_root}/{path}?apikey={apikey}&{url_args}".format(
-            api_root=API_ROOT,
+        url = "{api_protocol}://{api_domain}/{path}?apikey={apikey}&{url_args}".format(
+            api_protocol=self._selected_protocol,
+            api_domain=API_DOMAIN,
             path=endpoint_path,
             apikey=apikey,
             url_args=sunlight.service.safe_encode(url_args)
@@ -294,7 +341,10 @@ class Congress(sunlight.service.Service):
         return url
 
     def _decode_response(self, response):
-        data = json.loads(response)
+        try:
+            data = json.loads(response)
+        except Exception:
+            raise SunlightException('Error parsing response! Something must be wrong with our Congress... API')
         results = data.pop('results', None)
         if results:
             return EntityList(results, data)
